==> react-lds-8.7.0.tgz: package/es/components/Button/Base/Button.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import ButtonIcon from './ButtonIcon';
var Button = React.forwardRef(function (props, ref) {
  var children = props.children,
      className = props.className,
      flavor = props.flavor,
      href = props.href,
      icon = props.icon,
      iconPosition = props.iconPosition,
      sprite = props.sprite,
      title = props.title,
      rest = _objectWithoutProperties(props, ["children", "className", "flavor", "href", "icon", "iconPosition", "sprite", "title"]);

  var hasFlavor = flavor != null && flavor !== 'none';
  var sldsClasses = cx('slds-button', _defineProperty({}, "slds-button_".concat(flavor), hasFlavor), className);
  var ButtonEl = href ? 'a' : 'button';
  var position = iconPosition || 'left';
  var content = children || title;
  var isShortcut = !!icon && !!sprite;
  var isRightShortcut = isShortcut && position !== 'left';
  return React.createElement(ButtonEl, _extends({}, rest, {
    className: sldsClasses,
    href: href,
    ref: ref,
    title: title
  }), isRightShortcut ? content : null, isShortcut && React.createElement(ButtonIcon, {
    position: position,
    icon: icon,
    sprite: sprite
  }), !isRightShortcut ? content : null);
});
Button.displayName = 'Button';
Button.defaultProps = {
  children: null,
  className: null,
  flavor: 'neutral',
  href: null,
  icon: null,
  iconPosition: null,
  sprite: null,
  title: null
};
Button.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Used to set content in advanced use cases
   */
  children: PropTypes.node,

  /**
   * Title attribute. Will be button content if no children are set
   */
  title: PropTypes.string,

  /**
   * Shortcut to render a button with an icon. Used together with `sprite`
   */
  icon: PropTypes.string,

  /**
   * Shortcut to render a button with an icon. Used together with `icon`
   */
  sprite: PropTypes.string,

  /**
   *  Shortcut to render a button with an icon. Can be "left" or "right". Used together with `icon`
   */
  iconPosition: PropTypes.oneOf(['left', 'right']),

  /**
   * Optional additional className
   */
  className: PropTypes.string,

  /**
   * Can be either `neutral`, `brand`, `outline-brand`, `destructive`, `text-destructive`, `success` or `inverse`
   * Default to `neutral`, set to "none" or `null` explicitely to render a plain button
   */
  flavor: PropTypes.oneOf(['brand', 'destructive', 'inverse', 'neutral', 'none', 'outline-brand', 'success', 'text-destructive', 'stretch']),

  /**
   * Optional href, renders as `a` when set
   */
  href: PropTypes.string
} : {};
export default Button;

==> react-lds-9.1.0.tgz: package/es/components/Button/Base/Button.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import ButtonIcon from './ButtonIcon';
var Button = React.forwardRef(function (props, ref) {
  var buttonEl = props.buttonEl,
      children = props.children,
      className = props.className,
      flavor = props.flavor,
      href = props.href,
      icon = props.icon,
      iconPosition = props.iconPosition,
      sprite = props.sprite,
      stretch = props.stretch,
      title = props.title,
      rest = _objectWithoutProperties(props, ["buttonEl", "children", "className", "flavor", "href", "icon", "iconPosition", "sprite", "stretch", "title"]);

  var hasFlavor = flavor != null && flavor !== 'none';
  var sldsClasses = cx('slds-button', _defineProperty({}, "slds-button_".concat(flavor), hasFlavor), {
    'slds-button_stretch': stretch && flavor !== 'stretch'
  }, className);
  var ButtonEl = href ? 'a' : buttonEl || 'button';
  var position = iconPosition || 'left';
  var content = children || title;
  var isShortcut = !!icon && !!sprite;
  var isRightShortcut = isShortcut && position !== 'left';
  return React.createElement(ButtonEl, _extends({}, rest, {
    className: sldsClasses,
    href: href,
    ref: ref,
    title: title
  }), isRightShortcut ? content : null, isShortcut && React.createElement(ButtonIcon, {
    position: position,
    icon: icon,
    sprite: sprite
  }), !isRightShortcut ? content : null);
});
Button.displayName = 'Button';
Button.defaultProps = {
  buttonEl: null,
  children: null,
  className: null,
  flavor: 'neutral',
  href: null,
  icon: null,
  iconPosition: null,
  sprite: null,
  stretch: false,
  title: null
};
Button.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Custom element (default is `button` or `a` when `href` is present)
   */
  buttonEl: PropTypes.string,

  /**
   * Used to set content in advanced use cases
   */
  children: PropTypes.node,

  /**
   * Title attribute. Will be button content if no children are set
   */
  title: PropTypes.string,

  /**
   * Shortcut to render a button with an icon. Used together with `sprite`
   */
  icon: PropTypes.string,

  /**
   * Shortcut to render a button with an icon. Used together with `icon`
   */
  sprite: PropTypes.string,

  /**
   *  Shortcut to render a button with an icon. Can be "left" or "right". Used together with `icon`
   */
  iconPosition: PropTypes.oneOf(['left', 'right']),

  /**
   * Optional additional className
   */
  className: PropTypes.string,

  /**
   * Can be either `neutral`, `brand`, `outline-brand`, `destructive`, `text-destructive`, `success` or `inverse`
   * Default to `neutral`, set to "none" or `null` explicitely to render a plain button
   * [DEPRECATED] `prop.stretch` should be used instd. of `flavor="stretch"`
   */
  flavor: PropTypes.oneOf(['brand', 'destructive', 'inverse', 'neutral', 'none', 'outline-brand', 'success', 'text-destructive', 'stretch']),

  /**
   * Optional href, renders as `a` when set
   */
  href: PropTypes.string,

  /**
   * Renders a full-width button
   */
  stretch: PropTypes.bool
} : {};
export default Button;
